<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<!--xsl:import href="../../../../share/XSLT/upperLinks.xsl"/-->
<xsl:import href="../../../../share/XSLT/bottomLinks.xsl"/>
<xsl:import href="../../../../share/XSLT/descriptionTop.xslt"/>

<xsl:import href="generate_example.xslt"/>
<xsl:import href="interface.xslt"/>
<xsl:import href="attribute.xslt"/>
<xsl:import href="method.xslt"/>

<xsl:param name="pwd"/>

<xsl:output method="xhtml:xhtml"/>

<xsl:key name="interface" match="@name" use="parent::interface/@name"/>
<xsl:key name="attribute" match="attribute" use="parent::interface/@name"/>
<xsl:key name="method" match="method" use="parent::interface/@name"/>

<xsl:param name="basePath"/>

<xsl:variable name="leaves">
  <tree xmlns="">
    <leaf id="Core" title="interfaces"/>
    <leaf id="HTML" title="attributes"/>
  </tree>
</xsl:variable>

<xsl:variable name="zvonItemid" select="document('../frontpage.xml')/frontPage/@idref"/>

<xsl:variable name="examplesDoc" select="document('../examples.xml')/examples"/>



<xsl:template match="/">
  <xsl:apply-templates select="//module"/>
</xsl:template>


<xsl:template match="module">
  <!-- INTERFACES -->
  <xsl:variable name="moduleName"><xsl:value-of select="@name"/></xsl:variable>
  <xsl:variable name="moduleStandard"><xsl:value-of select="@standard"/></xsl:variable>
  <xsl:for-each select="descendant::interface">
    <xsl:variable name="outputFile">
      <xsl:text>interface_</xsl:text><xsl:value-of select="@name"/><xsl:text>.html</xsl:text>
    </xsl:variable>
    <xsl:document indent="yes" method="xhtml:xhtml" href="{$pwd}Output/{$moduleName}/{$outputFile}">
      <xsl:call-template name="interface">
        <xsl:with-param name="module"><xsl:value-of select="$moduleName"/></xsl:with-param>
        <xsl:with-param name="standard"><xsl:value-of select="$moduleStandard"/></xsl:with-param>
      </xsl:call-template>
    </xsl:document>
    <!-- ATTRIBUTES and METHODS -->
    <xsl:call-template name="interfaceAttributes">
      <xsl:with-param name="module"><xsl:value-of select="$moduleName"/></xsl:with-param>
      <xsl:with-param name="standard"><xsl:value-of select="$moduleStandard"/></xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="interfaceMethods">
      <xsl:with-param name="module"><xsl:value-of select="$moduleName"/></xsl:with-param>
      <xsl:with-param name="standard"><xsl:value-of select="$moduleStandard"/></xsl:with-param>
    </xsl:call-template>
  </xsl:for-each>
</xsl:template>


<!-- HEADER -->
<xsl:template name="header">
  <xsl:param name="standard"/>
  <xsl:param name="module"/>
  <xsl:param name="interface"/>
  <xsl:param name="property"/>
  <xsl:call-template name="descriptionTop"/>
  <table width="100%" border="0" cellpadding="0" cellspacing="0" class="menu">
     <tr>
        <!--td>&#160;&#160;&#160;<a class="menuH" href="javascript: history.back()">[Back]</a></td-->
        <td>
          &#160;&#160;&#160;
          <xsl:call-template name="structure">
            <xsl:with-param name="module" select="$module"/>
            <xsl:with-param name="interface" select="$interface"/>
            <xsl:with-param name="property" select="$property"/>
          </xsl:call-template>
        </td>
        <td class="right">
          <a class="menuH" href="{$standard}#{@standard}">[Go to standard]</a>&#160;
          <a class="menuH" href="../_glossary.html">[Glossary]</a>&#160;
          <a class="menuH" href="../_help.html">[Help]</a>&#160;&#160;&#160;
        </td>
     </tr>
  </table>
  <!--xsl:call-template name="upperLinks"/-->
</xsl:template>

<!-- FOOTER -->
<xsl:template name="footer">
  <xsl:call-template name="bottomLinks"/>
</xsl:template>

<!-- ATTRIBUTES and METHODS -->
<xsl:template name="interfaceAttributes">
  <xsl:param name="module"/>
  <xsl:param name="standard"/>
  <xsl:for-each select="attribute">
    <xsl:variable name="outputFile">
      <xsl:text>attribute_</xsl:text><xsl:value-of select="@name"/><xsl:text>_</xsl:text><xsl:value-of select="../@name"/><xsl:text>.html</xsl:text>
    </xsl:variable>
    <xsl:document indent="yes" method="xhtml:xhtml" href="{$pwd}Output/{$module}/{$outputFile}">
      <xsl:call-template name="attribute">
        <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        <xsl:with-param name="standard"><xsl:value-of select="$standard"/></xsl:with-param>
      </xsl:call-template>
    </xsl:document>
  </xsl:for-each>
</xsl:template>
<xsl:template name="interfaceMethods">
  <xsl:param name="module"/>
  <xsl:param name="standard"/>
  <xsl:for-each select="method">
    <xsl:variable name="outputFile">
      <xsl:text>method_</xsl:text><xsl:value-of select="@name"/><xsl:text>_</xsl:text><xsl:value-of select="../@name"/><xsl:text>.html</xsl:text>
    </xsl:variable>
    <xsl:document indent="yes" method="xhtml:xhtml" href="{$pwd}Output/{$module}/{$outputFile}">
      <xsl:call-template name="method">
        <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        <xsl:with-param name="standard"><xsl:value-of select="$standard"/></xsl:with-param>
      </xsl:call-template>
    </xsl:document>
  </xsl:for-each>
</xsl:template>


<!-- global templates -->

<!--xsl:template match="*|@*">
  <xsl:copy>
    <xsl:apply-templates select="node()|@*"/>
  </xsl:copy>
</xsl:template-->

<xsl:template match="standard">
  <span  class="standard">
    <xsl:apply-templates select="node()|@*"/>
  </span>
</xsl:template>

<xsl:template match="code">
  <xsl:variable name="link">
    <xsl:choose>
      <xsl:when test=".='XML Namespaces'">
        <xsl:text>namespaces</xsl:text>
      </xsl:when>
      <xsl:when test="(.='namespace URI') or (.='namespace prefix') or (.='local name')">
        <xsl:value-of select="substring-before(.,' ')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="."/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <a href="../_glossary.html#{$link}" class="code"><xsl:value-of select="."/></a>
</xsl:template>

<xsl:template name="interfaceDetector">
  <xsl:choose>
    <xsl:when test="@type='DOMString' or @type='Boolean' or @type='DOMException' or @type='unsigned long' or @type='unsigned short'">
      <xsl:choose>
        <xsl:when test="@type='unsigned long' or @type='unsigned short'">
          <a href="../_glossary.html#unsigned" class="code">
            <xsl:value-of select="@type"/>
          </a>
        </xsl:when>
        <xsl:otherwise>
          <a href="../_glossary.html#{@type}" class="code">
            <xsl:value-of select="@type"/>
          </a>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise> <!-- so it must be interface -->
      <xsl:variable name="path">
        <xsl:text>interface_</xsl:text><xsl:value-of select="@type"/><xsl:text>.html</xsl:text>
      </xsl:variable>
      <a href="{$path}" class="interface"><xsl:value-of select="@type"/></a>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="infc">
  <xsl:variable name="path">
    <xsl:text>interface_</xsl:text><xsl:value-of select="child::node()"/><xsl:text>.html</xsl:text>
  </xsl:variable>
  <a href="{$path}" class="interface"><xsl:value-of select="child::node()"/></a>
</xsl:template>

<xsl:template match="attr">
  <xsl:variable name="path">
    <xsl:text>attribute_</xsl:text><xsl:value-of select="."/><xsl:text>_</xsl:text><xsl:value-of select="@for"/><xsl:text>.html</xsl:text>
  </xsl:variable>
  <a href="{$path}" class="attributeFg"><xsl:value-of select="child::node()"/></a>
</xsl:template>

<xsl:template match="mtd">
  <xsl:variable name="path">
    <xsl:text>method_</xsl:text><xsl:value-of select="."/><xsl:text>_</xsl:text><xsl:value-of select="@for"/><xsl:text>.html</xsl:text>
  </xsl:variable>
  <a href="{$path}" class="methodFg"><xsl:value-of select="child::node()"/></a>
</xsl:template>

<xsl:template match="prm">
  <span class="parameter"><xsl:value-of select="child::node()"/></span>
</xsl:template>

<xsl:template match="exception">
  <dl>
    <dt>
      <!-- Because there is only one type of exceptions - DOMException - one hardcoded <span> for it. -->
      <a href="../_glossary.html#{@type}" class="code"><xsl:value-of select="@type"/></a>&#160;<xsl:value-of select="@name"/>
    </dt>
    <dd>
      <xsl:apply-templates select="desc"/>
    </dd>
  </dl>
</xsl:template>

<xsl:template match="interface" mode="members">
  <xsl:choose>
    <xsl:when test="name(..)='parent' and ../following-sibling::children">
      <xsl:apply-templates select="../following-sibling::children//interface" mode="list">
        <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>none</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
<xsl:template match="interface" mode="list">
  <a class="interface" href="interface_{@name}.html">
    <xsl:value-of select="@name"/>
  </a>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>

<xsl:template name="structure">
  <xsl:param name="module"/>
  <xsl:param name="interface"/>
  <xsl:param name="property">null</xsl:param>
  <!--xsl:message>
    STRUCTURE called for <xsl:value-of select="$interface"/> &amp; <xsl:value-of select="$property"/>
  </xsl:message-->
  <span class="mediumText">
    <a class="naviBlack" href="../index.html" target="_top">DOM2 reference</a>
    <xsl:text> &gt; </xsl:text>
    <b><xsl:value-of select="$module"/><xsl:text>: </xsl:text></b>
    <xsl:choose>
      <xsl:when test="($module='Core') and not($property='null')">
        <a class="naviBlack" href="../Core/interface_{$interface}.html"><xsl:value-of select="$interface"/></a>
      </xsl:when>
      <xsl:when test="($module='HTML') and not($property='null')">
        <a class="naviBlack" href="../HTML/interface_{$interface}.html"><xsl:value-of select="$interface"/></a>
      </xsl:when>
      <xsl:otherwise>
        <b><xsl:value-of select="$interface"/></b>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="not($property='null')">
      <xsl:text> &gt; </xsl:text>
      <b><xsl:value-of select="$property"/></b>
    </xsl:if>
  </span>
</xsl:template>



<!-- ZVON related -->
<xsl:template name="descriptionTop">
  <xsl:call-template name="share_descriptionTop">
    <xsl:with-param name="id" select="$zvonItemid"/>
    <xsl:with-param name="levelsBack" select="2"/>
  </xsl:call-template>
</xsl:template>
 


</xsl:stylesheet>
