<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:output method="xhtml:xhtml"/>


<!-- ATTRIBUTE -->
<xsl:template name="attribute">
  <xsl:param name="module"/>
  <xsl:param name="standard"/>
  <xsl:param name="interface"><xsl:value-of select="../@name"/></xsl:param>
  <html>
    <head>
      <title> Attribute <xsl:value-of select="@name"/> of interface <xsl:value-of select="$interface"/> </title>
      <link href="../global.css" rel="stylesheet" type="text/css" />
      <link href="../reference.css" rel="stylesheet" type="text/css" />
      <link href="../example.css" rel="stylesheet" type="text/css" />
    </head>
    <body>
    
      <!-- HEADER -->
      <xsl:call-template name="header">
        <xsl:with-param name="standard"><xsl:value-of select="$standard"/></xsl:with-param>
        <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        <xsl:with-param name="interface"><xsl:value-of select="$interface"/></xsl:with-param>
        <xsl:with-param name="property"><xsl:value-of select="@name"/></xsl:with-param>
      </xsl:call-template>
      
      <!-- ATTRIBUTE body -->
      <h2>
        <xsl:value-of select="@name"/>
        (attribute
        <xsl:if test="@deprecated='yes'">
          <xsl:text>,&#160;</xsl:text>
          <span class="deprecated">deprecated in HTML 4.01</span>
        </xsl:if>
        )
      </h2>

      <div class="bold2">Owning interface and usage: &#160; </div>
      <div class="dataBody">
        <a href="interface_{$interface}.html" class="interface"><xsl:value-of select="$interface"/></a><xsl:text>.</xsl:text><span class="attribute"><xsl:value-of select="@name"/></span>
      </div>

      <br />
      <div class="bold2">Member of these other interfaces : &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select=".." mode="members"/>
      </div>

      <br />
      <div>
        <span class="bold2">Readonly: &#160; </span>
        <xsl:value-of select="@readonly"/>
      </div>

      <br />
      <div>
        <span class="bold2">Type: &#160; </span>
        <xsl:call-template name="interfaceDetector"/>
      </div>

      <br />
      <div class="bold2">Description: &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select="description|descr"/>
      </div>

    <xsl:if test="not(normalize-space(note)='')">
      <br />
      <div class="bold2">Note: &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select="note"/>
      </div>
    </xsl:if>

      <xsl:if test="group">
        <br />
        <xsl:apply-templates select="group"/>
      </xsl:if>

    <xsl:if test="exception">
      <br />
      <div class="bold2">Exception: &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select="exception"/>
      </div>
    </xsl:if>

    <xsl:if test="$examplesDoc//example[@forInterface=current()/parent::interface/@name and @forName=current()/@name]">
      <br />
      <br />
      <a name="example"/>
      <fieldset>
        <legend class="bold2">Example:</legend>
        <div>
          <xsl:apply-templates select="$examplesDoc//example[@forInterface=current()/parent::interface/@name and @forName=current()/@name]"/>
        </div>
      </fieldset>
    </xsl:if>

    <!-- FOOTER -->
    <xsl:call-template name="footer"/>

    </body>
  </html>
</xsl:template>

</xsl:stylesheet>
