<xsl:stylesheet xmlns:xsl='http://www.w3.org/1999/XSL/Transform' xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon" version="1.1"> 

<xsl:import href="headers.xslt"/>

<xsl:param name="pwd"/>
<xsl:param name="basePath"/>


<xsl:variable name="css">../CSS/style.css</xsl:variable>

<xsl:output method="html"/>

<xsl:template match="/">
  <html>
    <head>
      <link rel="stylesheet" type="text/css" href="{$css}"/> 
      <title>XSLT 1.0: functions</title>
    </head>
    <body>
      <xsl:call-template name="index-header">
	<xsl:with-param name="on">function</xsl:with-param>
	<xsl:with-param name="id" select="$zvonItemid"/>
      </xsl:call-template>

      <xsl:apply-templates select="//function | document('../Data/xsltFunctions.xml')//function">
	<xsl:sort select="@name"/>
      </xsl:apply-templates>
    </body>
  </html>
</xsl:template>


<xsl:template match="function">
  <div>
    <a href="function_{@name}.html" target="mainWindow"><xsl:value-of select="@name"/></a>
  </div>

    <xsl:document href="{$pwd}../Output/function_{@name}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="{$css}"/>
	<title>XSLT 1.0: function <xsl:value-of select="@name"/></title>
      </head>
      <body>
	<xsl:variable name="st">
	  <xsl:choose>
	    <xsl:when test="starts-with(name(/*),'xslt')">xslt</xsl:when>
	    <xsl:otherwise>xpath</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:variable name="label">
	  <xsl:choose>
	    <xsl:when test="starts-with(name(/*),'xslt')">XSLT</xsl:when>
	    <xsl:otherwise>XPath</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:call-template name="share_descriptionTop">
	  <xsl:with-param name="id" select="$zvonItemid"/>
	</xsl:call-template>

	<xsl:call-template name="description-header">
	  <xsl:with-param name="standard">
	    <xsl:value-of select="concat($st,'.html#',@standardAnchor)"/>
	  </xsl:with-param>
	</xsl:call-template>
	<h3>
	  <xsl:text></xsl:text>
	  <xsl:value-of select="$label"/>
	  <xsl:text> function: </xsl:text>
	  <span class="return"><xsl:value-of select="@return"/></span> <xsl:text> </xsl:text>
	  <span class="name"><xsl:value-of select="@name"/></span>  <xsl:text> (</xsl:text>
	  <xsl:apply-templates select="argument"/>
	  <xsl:text>)</xsl:text>
	</h3>
	<p>
	  <xsl:apply-templates select="attribute"/></p>
	  <h3>Standard excerpt:</h3>
	  <xsl:value-of select="standard"/>
	  <hr/>
	  <b>Examples (xslt:xml): </b> 
	  <a href='../OutputOverview/function_{@name}_frame.html'>Overview</a><br/>
	  <xsl:comment>AllStart</xsl:comment>
	  <xsl:comment>AllEnd</xsl:comment>
	  <p><b>Interactive xlab: </b>
	    <xsl:apply-templates select="document('../Data/xlab.xml')/xlab/xl/function[normalize-space(.)=current()/@name]"/>
	    <xsl:apply-templates select="document('../Data/xlab.xml')/xlab/xl/functions"/>
	</p>
	</body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template match="xl/function | xl/functions">
  <a href="{../@url}" target='_blank'> [<xsl:value-of select="../@name"/>] </a>
</xsl:template>

<xsl:template match="argument">
  <span class="argument"><xsl:value-of select="@type"/>
  <xsl:if test="@occur='zero-multiple'">*</xsl:if>
  <xsl:if test="@occur='zero-once'">?</xsl:if>

</span>
  <xsl:if test="not(position()=last())">
    <xsl:text>, </xsl:text>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>



